@@ -218,6 +218,18 @@ class ServiceDocumentEventHandler(CLIDocumentEventHandler):
 
 class OperationDocumentEventHandler(CLIDocumentEventHandler):
 
+    def __init__(self, help_command):
+        super(OperationDocumentEventHandler, self).__init__(help_command)
+        self._arg_groups = self._build_arg_table_groups(help_command)
+        self._documented_arg_groups = []
+
+    def _build_arg_table_groups(self, help_command):
+        arg_groups = {}
+        for name, arg in help_command.arg_table.items():
+            if arg.group_name is not None:
+                arg_groups.setdefault(arg.group_name, []).append(arg)
+        return arg_groups
+
     def build_translation_map(self):
         LOG.debug('build_translation_map')
         operation = self.help_command.obj
@@ -268,8 +280,17 @@ class OperationDocumentEventHandler(CLIDocumentEventHandler):
     def doc_option(self, arg_name, help_command, **kwargs):
         doc = help_command.doc
         argument = help_command.arg_table[arg_name]
-        doc.write('``%s`` (%s)\n' % (argument.cli_name,
-                                     argument.cli_type_name))
+        if argument.group_name in self._arg_groups:
+            if argument.group_name in self._documented_arg_groups:
+                # This arg is already documented so we can move on.
+                return
+            name = ' | '.join(
+                ['``%s``' % a.cli_name for a in
+                 self._arg_groups[argument.group_name]])
+            self._documented_arg_groups.append(argument.group_name)
+        else:
+            name = '``%s``' % argument.cli_name
+        doc.write('%s (%s)\n' % (name, argument.cli_type_name))
         doc.style.indent()
         doc.include_doc_string(argument.documentation)
         doc.style.dedent()
@@ -346,13 +367,30 @@ class OperationDocumentEventHandler(CLIDocumentEventHandler):
         argument = help_command.arg_table[arg_name]
         param = argument.argument_object
         if param and param.example_fn:
+            # TODO: bcdoc should not know about shorthand syntax. This
+            # should be pulled out into a separate handler in the
+            # awscli.customizations package.
             doc.style.new_paragraph()
             doc.write('Shorthand Syntax')
             doc.style.start_codeblock()
             for example_line in param.example_fn(param).splitlines():
                 doc.writeln(example_line)
             doc.style.end_codeblock()
-        if argument.cli_type_name not in SCALARS:
+        if param is not None and param.type == 'list' and \
+                param.members.type in SCALARS:
+            # A list of scalars is special.  While you *can* use
+            # JSON ( ["foo", "bar", "baz"] ), you can also just
+            # use the argparse behavior of space separated lists.
+            # "foo" "bar" "baz".  In fact we don't even want to
+            # document the JSON syntax in this case.
+            doc.style.new_paragraph()
+            doc.write('Syntax')
+            doc.style.start_codeblock()
+            example_type = self._json_example_value_name(param.members)
+            doc.write('%s %s ...' % (example_type, example_type))
+            doc.style.end_codeblock()
+            doc.style.new_paragraph()
+        elif argument.cli_type_name not in SCALARS:
             doc.style.new_paragraph()
             doc.write('JSON Syntax')
             doc.style.start_codeblock()
